@@ -47,11 +47,12 @@
 /////////////////////// Local includes
 #include "BasePlotWnd.hpp"
 #include "ProgramWindow.hpp"
-#include "ColorSelector.hpp"
 #include "MzIntegrationParamsDlg.hpp"
 #include "MsFragmentationSpecDlg.hpp"
 #include "Application.hpp"
 #include "PlotAreaOverlay.hpp"
+#include "../nongui/MassDataIntegratorTask.hpp"
+
 
 
 namespace msxps
