@@ -34,6 +34,8 @@
 #include <iostream>
 #include <cstdio>
 #include <iomanip>
+#include <pappsomspp/msfile/msfileaccessor.h>
+#include <pappsomspp/types.h>
 #include <thread>
 #include <ctime>
 
@@ -54,7 +56,9 @@
 #include <QThread>
 #include <QDateTime>
 
+
 /////////////////////// pappsomspp includes
+#include <pappsomspp/utils.h>
 #include <pappsomspp/processing/combiners/tracepluscombiner.h>
 #include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
@@ -62,13 +66,8 @@
 /////////////////////// Local includes
 #include "Application.hpp"
 #include "ProgramWindow.hpp"
-#include "MsRunDataSetTableView.hpp"
-#include "MsRunDataSetTableViewModel.hpp"
-#include "MsRunDataSetTableViewProxyModel.hpp"
-#include "../nongui/globals.hpp"
 #include "MsRunReadTask.hpp"
 #include "../nongui/MassDataIntegrator.hpp"
-#include "ColorSelector.hpp"
 #include "MsRunSelectorDlg.hpp"
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "../nongui/MsRunDataSet.hpp"
@@ -106,7 +105,6 @@ ProgramWindow::moduleName() const
   return m_moduleName;
 }
 
-
 void
 ProgramWindow::setMaxThreadUseCount(std::size_t count)
 {
@@ -125,7 +123,7 @@ bool
 ProgramWindow::openMassSpectrometryFileDlg(const QString &dir_name,
                                            bool full_in_memory)
 {
-  //qDebug() << "The directory name is:" << dir_name;
+  // qDebug() << "The directory name is:" << dir_name;
 
   QFileDialog file_dialog(
     this,
@@ -203,6 +201,17 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
 
   // qDebug() << "Could get MsFileAccessor.";
 
+  // Note that if the data type is from Bruker:timsTOF, then we want a specific
+  // ms run reader to start with.
+  // if(ms_file_accessor.getFileFormat() == pappso::MzFormat::brukerTims)
+
+  // Preventively set the preferred ms file reader type in case the reader is
+  // Bruker-tims. This setting  will be accounted for when calling
+  // MsFileAccessor::getMsRunIds() later on.
+
+  ms_file_accessor.setPreferedFileReaderType(
+    pappso::MzFormat::brukerTims, pappso::FileReaderType::tims_frames);
+
   std::vector<pappso::MsRunIdCstSPtr> ms_run_ids =
     ms_file_accessor.getMsRunIds();
 
@@ -214,7 +223,7 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
     {
       QMessageBox::information(this,
                                "Open mass spectrometry file",
-                               "This file does contain no MS run");
+                               "This file does not contain any MS run");
       return false;
     }
 
@@ -239,6 +248,18 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
         return false;
     }
 
+  qDebug() << "The file format was detected as:"
+           << pappso::Utils::mzFormatAsString(ms_file_accessor.getFileFormat());
+
+  if(ms_file_accessor.getFileFormat() == pappso::MzFormat::brukerTims)
+    {
+      QMessageBox msg_box;
+      msg_box.setText(
+        "The Bruker timsTOF data import is experimental.\nAll the mobility "
+        "scans are combined into one single mass spectrum.");
+      msg_box.exec();
+    }
+
   // Now actually load the data!
 
   // Allocate a ms run reader task to read the data.
@@ -301,7 +322,7 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
           &MassSpecDataFileLoader::cancelOperation);
 
   // We need to register the meta type for std::size_t because otherwise it
-  // cannobe shipped though signals.
+  // cannot be shipped through signals.
 
   qRegisterMetaType<std::size_t>("std::size_t");
 
@@ -699,7 +720,7 @@ ProgramWindow::integrateToRt(
 
 void
 ProgramWindow::integrateToTicIntensity(
-[[maybe_unused]] QCPAbstractPlottable *parent_plottable_p,
+  [[maybe_unused]] QCPAbstractPlottable *parent_plottable_p,
   std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>
     qualified_mass_spectra_sp,
   const ProcessingFlow &processing_flow)
@@ -1377,7 +1398,7 @@ ProgramWindow::finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp)
   // Let's see the usage count of the MsRunDataSetCstSPtr.
   // qDebug() << "Usage count:" << ms_run_data_set_sp.use_count();
 
-  #if 0
+#if 0
   // Let's control how the data loading process went.
 
   pappso::MsRunDataSetTreeCstSPtr ms_run_data_set_tree_csp =
@@ -1392,7 +1413,7 @@ ProgramWindow::finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp)
            << ms_run_data_set_tree_csp->depth()
            << "and the index node map has this number of items:"
            << index_node_map.size();
-  #endif
+#endif
 
   // We want to try the multi-visitor approach: a single visitor that contains a
   // vector of visitors. This is interesting because it makes reading the mass
@@ -1401,6 +1422,15 @@ ProgramWindow::finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp)
   // Let's see the usage count of the MsRunDataSetCstSPtr.
   // qDebug() << "Usage count:" << ms_run_data_set_sp.use_count();
 
+#if 0
+  // IF BRUKER DATA
+  // To debug we can ask that the ms run reader provides us with the TIC
+  // chromaogram from the Bruker timsTOF data SQL database.
+  
+  pappso::Trace tic_chromatogram = ms_run_data_set_sp->getMsRunReaderSPtr()->getTicChromatogram();
+  qDebug() << "Tic Chromatogram: \n" << tic_chromatogram.toString();
+#endif
+
   seedInitialTicChromatogramAndMsRunDataSetStatistics(ms_run_data_set_sp);
 
   // Let's see the usage count of the MsRunDataSetCstSPtr.
@@ -1552,7 +1582,6 @@ ProgramWindow::seedInitialTicChromatogramAndMsRunDataSetStatistics(
 }
 
 
-
 void
 ProgramWindow::finishedSeedingInitialTicChromatogramAndMsRunDataSetStatistics(
   MassDataIntegrator *mass_data_integrator_p)
@@ -1840,7 +1869,6 @@ ProgramWindow::initializeAllWindows()
   // NO, this one is "on demand".
   // mp_massPeakShaperDlg = new MassPeakShaperDlg(this, m_moduleName);
 
-
   // At this point, try to check if we should remind the user to
   // cite the paper.
 
@@ -2112,10 +2140,9 @@ ProgramWindow::createMenusAndActions()
   connect(action_p, &QAction::triggered, this, &ProgramWindow::showAboutDlg);
   mp_helpMenu->addAction(action_p);
 
-  action_p =
-    new QAction(QIcon(":/images/svg/help-qt-information-icon.svg"),
-                tr("About &Qt"),
-                dynamic_cast<QObject *>(this));
+  action_p = new QAction(QIcon(":/images/svg/help-qt-information-icon.svg"),
+                         tr("About &Qt"),
+                         dynamic_cast<QObject *>(this));
   action_p->setStatusTip(tr("Show the Qt &library's About box"));
   connect(action_p, &QAction::triggered, this, &Application::aboutQt);
   action_p->setShortcut(QKeySequence("Ctrl+H, Q"));
@@ -2136,7 +2163,7 @@ ProgramWindow::setupWindow()
   // This attribute make sure that the main window of the program is destroyed
   // when it is closed. Effectively stopping the program.
   setAttribute(Qt::WA_DeleteOnClose);
-  
+
   statusBar()->setSizeGripEnabled(true);
 
   createMenusAndActions();
@@ -2354,6 +2381,3 @@ ProgramWindow::showMsRunDataSetTableViewWnd(
 } // namespace minexpert
 
 } // namespace msxps
-
-
-
