@@ -243,7 +243,7 @@ void
 TicXicChromTracePlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
 {
-   qDebug().noquote() << "context:" << context.toString();
+   //qDebug().noquote() << "context:" << context.toString();
 
   // Make a local copy of the context because we may need to modify it.
   pappso::BasePlotContext local_context = context;
@@ -270,7 +270,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
 
   local_context.m_selectionPolygon.rangeX(range_start, range_end);
 
-  qDebug() << "selection polygon:" << local_context.m_selectionPolygon.toString();
+  //qDebug() << "selection polygon:" << local_context.m_selectionPolygon.toString();
   //qDebug() << "X axis range:" << range_start << "-" << range_end;
 
   // Having negative retention times does not make any sense.
@@ -315,15 +315,15 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   // Create a local copy of the processing flow so that we can modify it by
   // adding the new processing step that describes what we are doing now.
 
-  qDebug();
+  //qDebug();
 
   ProcessingFlow local_processing_flow =
     getProcessingFlowForPlottable(plottable_p);
 
-  qDebug() << local_processing_flow.getMsRunDataSetCstSPtr()->getMsRunId()->getFileName();
+  //qDebug() << local_processing_flow.getMsRunDataSetCstSPtr()->getMsRunId()->getFileName();
 
-  qDebug().noquote() << "Processing flow for graph:"
-                     << local_processing_flow.toString();
+  //qDebug().noquote() << "Processing flow for graph:"
+                     //<< local_processing_flow.toString();
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(plottable_p);
@@ -363,11 +363,11 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   // Now make sure we document the selection polygon.
   // Now define the graph range for the integration operation.
 
-  qDebug();
+  //qDebug();
 
   processing_step_p->setSelectionPolygon(local_context.m_selectionPolygon);
 
-  qDebug();
+  //qDebug();
 
   // We must say what is the data source processing type.
   processing_step_p->setSrcProcessingType(pappso::Axis::x, "RT");
@@ -475,7 +475,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
       // last one.
       local_processing_flow.push_back(processing_step_p);
 
-      qDebug();
+      //qDebug();
 
       // The local processing flow contains all the previous steps and the last
       // one that documents this current integration.
@@ -541,7 +541,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
         QMessageBox::StandardButton::NoButton);
     }
 
-  qDebug();
+  //qDebug();
 
   return;
 }
